IRC Bot Behavior Bundle (IB3) Documentation
===========================================

IRC bot framework using mixins to provide commonly desired functionality.

.. image:: https://img.shields.io/pypi/v/ib3.svg
   :target: https://pypi.org/project/ib3

.. image:: https://img.shields.io/travis/bd808/python-ib3/master.svg
   :target: http://travis-ci.org/bd808/python-ib3

.. image:: https://readthedocs.org/projects/python-ib3/badge/?version=latest
   :target: https://python-ib3.readthedocs.io

.. image:: https://img.shields.io/pypi/l/ib3.svg
   :target: https://github.com/bd808/python-ib3/blob/master/COPYING

.. image:: https://img.shields.io/github/forks/bd808/python-ib3.svg?style=social&label=Fork
   :target: https://github.com/bd808/python-ib3

.. toctree::
   :maxdepth: 2

   about
   ib3
